@@ -30,7 +30,9 @@ sub publish {
     my($self, $data) = @_;
     $data ||= $self->_get_data();
     my $path = $self->get_output_path;
-    my $fh = IO::File->new($path, "a")
+    my $mode = ">>";
+    $mode .= ":encoding(UTF-8)" if $path =~ m/html$/;
+    my $fh = IO::File->new($path, $mode)
         or $self->_croak(qq/Can't open $path./);
     $fh->seek(0, 0);
     $fh->truncate(0);
